@@ -1,12 +1,17 @@
-from .athena import AthenaClient, AthenaClientError
-from .s3_lib import S3Client, S3ClientError
+from .s3_lib import S3Client, S3ClientError, S3Location
 from .task_queue import TaskQueue
+from .athena import AthenaClient, AthenaClientError
+from .dynamodb import DynamoDB
 from .s3csv2parquet import S3Csv2Parquet, S3Csv2ParquetConversionError
+from .task_queue import RetryException
 
 __all__ = ['AthenaClient',
            'AthenaClientError',
+           'DynamoDB',
            'S3Client',
            'S3ClientError',
            'S3Csv2Parquet',
+           'S3Location',
            'TaskQueue',
-           'S3Csv2ParquetConversionError']
+           'S3Csv2ParquetConversionError',
+           'RetryException']
