@@ -1,13 +1,17 @@
 # (c) 2012-2018 Dativa, all rights reserved
 # -----------------------------------------
 #  This code is licensed under MIT license (see license.txt for details)
-import boto3
 from dativa.tools.aws import S3Client
 from dativa.tools.aws import TaskQueue
 import logging
 from os import path
 import time
 
+try:
+    import boto3
+except ImportError:
+    boto3 = None
+
 logger = logging.getLogger("dativa.tools.aws")
 
 
@@ -47,6 +51,9 @@ class S3Csv2Parquet(TaskQueue):
         """
 
         # Glue does not allow more than three runs of the same job
+        if not boto3:
+            raise ImportError("boto3 must be installed to run S3Csv2Parquet")
+
         super(S3Csv2Parquet, self).__init__(max_jobs, retry_limit, max_tasks_same_name=3)
 
         self.glue = boto3.client(service_name='glue', region_name=region,
@@ -87,7 +94,7 @@ class S3Csv2Parquet(TaskQueue):
                        If set source csv files are deleted post successful completion of job
         - separator - character, default ','
                       Delimiter character in csv files
-        - withHeader- int, default 1
+        - with_header- int, default 1
                       Specifies whether to treat the first line as a header
                       Can take values 0 or 1
         - compression - str, default None
@@ -239,10 +246,10 @@ class S3Csv2Parquet(TaskQueue):
 
         for each_file in csv_path:
             if each_file[:5] != "s3://":
-                logging.error("csv_path {} is not of format \
-                              s3://bucketname/folder".format(each_file))
-                raise S3Csv2ParquetConversionError("csv_path {} is not of \
-                                                   format s3://bucketname/folder".format(each_file))
+                logging.error("csv_path {} is not of format "
+                              "s3://bucketname/folder".format(each_file))
+                raise S3Csv2ParquetConversionError("csv_path {} is not of "
+                                                   "format s3://bucketname/folder".format(each_file))
 
         if not isinstance(output_folder, str) and output_folder is not None:
             logging.error("output_folder must be of type string got {} instead".format(str(type(output_folder))))
@@ -250,10 +257,10 @@ class S3Csv2Parquet(TaskQueue):
                                                format(str(type(output_folder))))
 
         if output_folder is not None and output_folder[:5] != "s3://":
-            logging.error("output_folder {} is not of format \
-                          s3://bucketname/folder".format(output_folder))
-            raise S3Csv2ParquetConversionError("output_folder {} is not of \
-                                               format s3://bucketname/folder".
+            logging.error("output_folder {} is not of format "
+                          "s3://bucketname/folder".format(output_folder))
+            raise S3Csv2ParquetConversionError("output_folder {} is not of "
+                                               "format s3://bucketname/folder".
                                                format(output_folder))
 
         if not isinstance(schema, list):
@@ -274,17 +281,17 @@ class S3Csv2Parquet(TaskQueue):
             raise S3Csv2ParquetConversionError("allocated capacity should be in range 2-100")
 
         if with_header not in [0, 1]:
-            logging.error("{} is not a valid value for withHeader it can only \
-                          take interger values 1 and 0".format(with_header))
-            raise S3Csv2ParquetConversionError("{} is not a valid value for \
-                                               withHeader it can only take \
-                                               interger values 1 and 0".format(with_header))
+            logging.error("{} is not a valid value for with_header it can only "
+                          "take integer values 1 and 0".format(with_header))
+            raise S3Csv2ParquetConversionError("{} is not a valid value for "
+                                               "with_header it can only take "
+                                               "integer values 1 and 0".format(with_header))
 
         if not isinstance(delete_csv, bool):
-            logging.error("{} is not a valid value for delete_csv.\
-                          It can only take boolean values")
-            raise S3Csv2ParquetConversionError("{} is not a valid value for delete_csv.\
-                          It can only take boolean values")
+            logging.error("{} is not a valid value for delete_csv."
+                          "It can only take boolean values")
+            raise S3Csv2ParquetConversionError("{} is not a valid value for delete_csv."
+                                               "It can only take boolean values")
 
         compression_methods = ['snappy', 'gzip', 'lzo']
         if compression is not None and compression not in compression_methods:
@@ -310,14 +317,14 @@ class S3Csv2Parquet(TaskQueue):
                                                format(str(type(separator))))
 
         if mode == 'overwrite' and output_folder is None:
-            logging.error("For mode:overwrite output_folder parameter must be specified and  \
-                           \n cannot be a parent directory of the csv_files")
-            raise S3Csv2ParquetConversionError("For mode:overwrite output_folder parameter must be specified and  \
-                                                \n cannot be a parent directory of the csv_files")
+            logging.error("For mode:overwrite output_folder parameter must be specified and"
+                          "\n cannot be a parent directory of the csv_files")
+            raise S3Csv2ParquetConversionError("For mode:overwrite output_folder parameter must be specified and"
+                                               "\n cannot be a parent directory of the csv_files")
         if mode == 'overwrite':
             for each_csv_file in csv_path:
                 if each_csv_file.startswith(output_folder):
-                    logging.error("For mode:overwrite output_folder cannot be a \
-                                   \n parent directory of the csv_files")
-                    raise S3Csv2ParquetConversionError("For mode:overwrite output_folder cannot be a \
-                                                        \n parent directory of the csv_files")
+                    logging.error("For mode:overwrite output_folder cannot be a"
+                                  "\n parent directory of the csv_files")
+                    raise S3Csv2ParquetConversionError("For mode:overwrite output_folder cannot be a"
+                                                       "\n parent directory of the csv_files")
