@@ -4,11 +4,17 @@ import csv
 import datetime
 from importlib import import_module
 
+try:
+    import sqlparse
+except ImportError:
+    sqlparse = None
+
 try:
     import pandas as pd
 except ImportError:
     pd = None
 
+
 class ParamParser:
     """
     Class to parse SQL parameters into a common format
@@ -104,7 +110,6 @@ class SqlClient:
         self._counter = 0
         self._log_query_text = log_query_text
 
-
     @staticmethod
     def _clean_dict(d):
         block_words = ["secret", "password"]
@@ -171,9 +176,18 @@ class SqlClient:
             text = text.replace(key, replace[key])
 
         # split into multiple commands....
-        for command in text.split(";"):
-            if command.strip() != "":
-                yield command.strip()
+        if ';' in text:
+            if not sqlparse:
+                # split into multiple commands....
+                for command in text.split(";"):
+                    if command.strip() != "":
+                        yield command.strip()
+
+            for command in sqlparse.split(text):
+                if command.strip() != "":
+                    yield command.strip()
+        else:
+            yield text.strip()
 
     def _run_and_log_sql(self, command, parameters, pandas=False, archive_query=False, dry_run=False):
 
@@ -236,7 +250,8 @@ class SqlClient:
 
         self.connection.commit()
 
-    def execute_query_to_df(self, query, parameters=None, replace=None, first_to_run=1, dry_run=False, archive_query=False):
+    def execute_query_to_df(self, query, parameters=None, replace=None, first_to_run=1, dry_run=False,
+                            archive_query=False):
         """
         Runs a query and returns the output of the final statement in a DataFrame.
 
