@@ -24,9 +24,12 @@ def get_column_name(df, column, total_columns=None):
         if column_index < 0:
             column_index = column_index + total_columns
         return df.columns.values.tolist()[column_index]
-    except ValueError:
-        from dativa.file_processing import FpInvalidSourceFieldError # noqa
-        raise FpInvalidSourceFieldError
+    except (ValueError, TypeError):  # we should be testing this?
+        try:
+            from dativa.file_processing import FpInvalidSourceFieldError  # noqa
+            raise FpInvalidSourceFieldError(column)
+        except ImportError:  # so let's qa it
+            raise KeyError('Invalid column name: {}'.format(column))
 
 
 def get_unique_column_name(df, name, suffix='_clean'):
