@@ -10,6 +10,7 @@ from dativa.tools.aws import S3Location, S3ClientError
 from functools import wraps
 from os import path
 import gzip
+import zipfile
 import s3fs
 import warnings
 
@@ -89,6 +90,11 @@ class CSVHandler:
     S3_PREFIX = "s3://"
     SAMPLE_SIZE = 1024 * 1024
 
+    allowed_read_compression = {'gzip', 'bz2', 'zip', 'xz', None, 'infer'}
+    allowed_quote_levels = {QUOTE_MINIMAL, QUOTE_ALL, QUOTE_NONNUMERIC, QUOTE_NONE}
+    allowed_zipfile_compressions = {zipfile.ZIP_DEFLATED, zipfile.ZIP_STORED, zipfile.ZIP_BZIP2, zipfile.ZIP_LZMA}
+    allowed_write_compressions = {'gzip', 'infer', 'zip'}
+
     detect_parameters = False
     base_path = ""
     include_index = False
@@ -111,6 +117,7 @@ class CSVHandler:
     aes_iv = None
     s3c_kwargs = {}
     pd_kwargs = {}
+    zipfile_compression = zipfile.ZIP_DEFLATED
 
     def __init__(self,
                  **kwargs):
@@ -160,13 +167,17 @@ class CSVHandler:
         self.value_or_default(kwargs, "usecols")
         self.value_or_default(kwargs, "names")
         self.value_or_default(kwargs, 'nrows')
+        self.value_or_default(kwargs, 'zipfile_compression')
 
-        if self.compression not in ['gzip', 'bz2', 'zip', 'xz', None, 'infer']:
+        if self.compression not in self.allowed_read_compression:
             raise ValueError("Invalid value for compression parameter")
 
-        if self.quoting not in [QUOTE_MINIMAL, QUOTE_ALL, QUOTE_NONNUMERIC, QUOTE_NONE]:
+        if self.quoting not in self.allowed_quote_levels:
             raise ValueError("Invalid value for quoting parameter")
 
+        if self.zipfile_compression not in self.allowed_zipfile_compressions:
+            raise ValueError("Invalid zip compression parameter")
+
         if self.aes_iv and not self.aes_key:
             raise ValueError("Cannot specify an aes_iv without an aes_key")
 
@@ -396,9 +407,9 @@ class CSVHandler:
 
         return df
 
-    def _get_csv_bytes(self, df):
-        if self.compression not in ['gzip', 'infer']:
-            raise ValueError("Only gzip compression is supported for writing dataframes")
+    def _get_csv_bytes(self, df, file):
+        if self.compression not in self.allowed_write_compressions:
+            raise ValueError("Only gzip or zip compression is supported for writing dataframes")
 
         if self.compression == 'gzip':
             buffer = BytesIO()
@@ -408,6 +419,17 @@ class CSVHandler:
             buffer.seek(0)
             return buffer.getvalue()
 
+        elif self.compression == 'zip':
+            file_name = file.rsplit('/')[-1]
+            file_name_no_extension = file_name.rsplit('.', 1)[0] if file_name.endswith('.zip') else file_name
+            csv_file_name = file_name_no_extension + '.csv'
+            buffer = BytesIO()
+            with zipfile.ZipFile(buffer, 'w', compression=self.zipfile_compression) as f:
+                f.writestr(csv_file_name, self._get_csv(df).encode(self.encoding))
+
+            buffer.seek(0)
+            return buffer.getvalue()
+
         else:
             return self._get_csv(df).encode(self.encoding)
 
@@ -441,7 +463,7 @@ class CSVHandler:
 
         self._process_kwargs(**kwargs)
 
-        bytes_to_write = self._get_csv_bytes(df)
+        bytes_to_write = self._get_csv_bytes(df, file)
         if self.aes_key:
             if not AES:
                 raise ValueError("Pycryptodomo is required to use an aes_key")
