@@ -223,6 +223,13 @@ class CSVOtherTests(unittest.TestCase):
         df2 = csv.load_df("gzip/test2.csv.gz")
         pd.testing.assert_frame_equal(df1, df2)
 
+    def test_zip(self):
+        csv = CSVHandler(base_path=self.orig_base_path, compression="zip")
+        df1 = csv.load_df("zip/test.csv.zip")
+        csv.save_df(df1, "zip/test2.csv.zip")
+        df2 = csv.load_df("zip/test2.csv.zip")
+        pd.testing.assert_frame_equal(df1, df2)
+
     def test_no_header(self):
         csv = CSVHandler(base_path=self.orig_base_path)
         df = csv.load_df("lookup/test_cities_reference1252.csv",
